class Program
{
    static readonly string[] IMAGE_EXTNAME = new string[] { "jpg"};
    static void Main(string[] args)
    {
        string savePath = @"E:\img\01\";
        string sourcePath = @"E:\img\02\";
        int scale = 5;

        List<string> imageNames = GetImageNames(sourcePath);
        if (imageNames != null && imageNames.Count > 0)
        {
            foreach (var item in imageNames)
            {
                SaveSmallPhoto(sourcePath + item, scale, savePath + item);
            }
        }
    }

    /// <summary>
    /// 获取路径下所有符合指定图片后缀文件名
    /// </summary>
    /// <param name="path">路径</param>
    /// <returns></returns>
    static List<string> GetImageNames(string path)
    {
        string[] fileNames = Directory.GetFiles(path);
        if (fileNames == null || fileNames.Length == 0)
        {
            return null;
        }

        List<string> imageNames = new List<string>();
        foreach (var item in fileNames)
        {
            if (ExistsInExtName(item, IMAGE_EXTNAME))
            {
                imageNames.Add(item.Substring(item.LastIndexOf('\\') + 1));
            }
        }

        return imageNames;
    }

    /// <summary>
    /// 判断文件名是否符合指定后缀名
    /// </summary>
    /// <param name="name">文件名</param>
    /// <param name="extNames">符合要求的后缀名</param>
    /// <returns></returns>
    static bool ExistsInExtName(string name, string[] extNames)
    {
        if (string.IsNullOrEmpty(name) || extNames == null || extNames.Length == 0)
        {
            return false;
        }

        foreach (var item in extNames)
        {
            if (name.ToLower().EndsWith(item))
            {
                return true;
            }
        }

        return false;
    }

    /// <summary>
    /// 将图片按比例缩小保存
    /// </summary>
    /// <param name="fromPath">原图片路径名</param>
    /// <param name="scale">缩小比例</param>
    /// <param name="toPath">缩小后保存的路径名</param>
    static void SaveSmallPhoto(string fromPath, int scale, string toPath)
    {
        int width, height;
        using (Image img = Image.FromFile(fromPath))
        {
            width = img.Width / scale;
            height = img.Height / scale;

            using (Image imgNew = new Bitmap(width, height))
            {
                using (Graphics g = Graphics.FromImage(imgNew))
                {
                    g.DrawImage(img, new Rectangle(0, 0, width, height),
                        new Rectangle(0, 0, img.Width, img.Height), System.Drawing.GraphicsUnit.Pixel);
                }

                imgNew.Save(toPath, ImageFormat.Jpeg);
            }
        }
    }
}